UC_pdf_document: Rbearcat PDF document

View source: R/uc_rmd.R

UC_pdf_documentR Documentation

Rbearcat PDF document

Description

An R Markdown output format for PDF documents.

Usage

UC_pdf_document(
  number_sections = FALSE,
  toc = FALSE,
  toc_depth = 2,
  highlight_bw = FALSE,
  in_header = NULL,
  ...
)

Arguments

number_sections

logical. Set to TRUE to number sections.

toc

logical. set to TRUE to include a table of contents.

toc_depth

number of layers in TOC.

highlight_bw

set to TRUE to convert colors in syntax highlighted code blocks to grayscale.

in_header

relative path to a tex formatting document included in the preamble. If NULL (default), function will use the preamble.tex file included with the package.

...

other options passed to bookdown::pdf_document2. See pdf_document2 and pdf_document for all available options.

Value

An rmarkdown::output_format object for rendering PDF documents.

Author(s)

Saannidhya Rawat


Rbearcat documentation built on March 21, 2026, 5:07 p.m.