View source: R/uc_presentation.R
| bcat_beamer | R Documentation |
An R Markdown output format for Beamer presentations (PDF).
bcat_beamer(in_header = NULL, ...)
in_header |
relative path to a tex formatting document included in the preamble.
If |
... |
other options passed to |
An rmarkdown::output_format object for rendering Beamer
presentations.
Saannidhya Rawat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.