bcat_fmt_date: Label dates/times

View source: R/bcat_fmts.R

bcat_fmt_dateR Documentation

Label dates/times

Description

A wrapper for base::format to convert character or date vector to specfied date/time format.

Usage

bcat_fmt_date(x, format = "%B %e, %Y", ...)

Arguments

x

a character or date/datetime vector

format

a date/time format string using standard POSIX specification

...

other arguments passed to format

Value

A character vector of formatted date or datetime labels with the same length as x.

See Also

Other formatting: bcat_fmt_comma(), bcat_fmt_dollar(), bcat_fmt_percent(), bcat_fmt_pvalue(), bcat_fmt_scientific()

Examples


bcat_fmt_date(Sys.Date())
bcat_fmt_date(c("2019-12-03", "2020-05-22"))

Rbearcat documentation built on March 21, 2026, 5:07 p.m.