bcat_gitbook: Rbearcat Gitbook

View source: R/bcat_book.R

bcat_gitbookR Documentation

Rbearcat Gitbook

Description

An R Markdown output format for the Gitbook format (HTML).

Usage

bcat_gitbook(css = NULL, after_body = NULL, collapse = "subsection", ...)

Arguments

css

relative path to a css formatting document. If NULL (default), function will use the style.css file included with the package.

after_body

relative path to HTML file to include after body of each chapter. If NULL (default), function will use the footer.html file included with the package.

collapse

specify level at which to collapse the table of contents.

...

other options passed to bookdown::gitbook

Value

An rmarkdown::output_format object for rendering Gitbook output.

Author(s)

Saannidhya Rawat


Rbearcat documentation built on March 21, 2026, 5:07 p.m.