bcat_pdf_book: Rbearcat PDF Book

View source: R/bcat_book.R

bcat_pdf_bookR Documentation

Rbearcat PDF Book

Description

An R Markdown output format for the PDF books.

Usage

bcat_pdf_book(in_header = NULL, before_body = NULL, toc_depth = 4, ...)

Arguments

in_header

relative path to a tex formatting document included in the preamble. If NULL (default), function will use the preamble.tex file included with the package.

before_body

relative path to a tex document included in before the body of the document. If NULL (default), function will use the before_body.tex file included with the package.

toc_depth

depth of headers to include in table of contents

...

other options passed to bookdown::pdf_book

Value

An rmarkdown::output_format object for rendering PDF books.

Author(s)

Saannidhya Rawat


Rbearcat documentation built on March 21, 2026, 5:07 p.m.