View source: R/bcat_setup_rmd.R
| bcat_setup_rmd | R Documentation |
Sets default code chunk options and configures options for kable tables. Call at the start of Rmd file in "setup" chunk.
bcat_setup_rmd()
No return value, called for side effects on knitr chunk defaults and table-related options.
Saannidhya Rawat
Other utilities:
bcat_extract_metadata(),
bcat_import_data(),
bcat_new_quarto(),
bcat_source_rmd()
# Call in your Rmd setup chunk:
bcat_setup_rmd()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.