View source: R/bcat_source_rmd.R
| bcat_source_rmd | R Documentation |
Utility function to run all code chunks in an Rmd file.
bcat_source_rmd(rmd)
rmd |
character. Rmd file from which to run all code chunks. |
An invisible list, as returned by base::source(), containing
the value of the last evaluated expression and whether it was visible.
Saannidhya Rawat
https://stackoverflow.com/questions/10966109/how-to-source-r-markdown-file-like-sourcemyfile-r
Other utilities:
bcat_extract_metadata(),
bcat_import_data(),
bcat_new_quarto(),
bcat_setup_rmd()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.