bcat_xaringan: UC Xaringan presentation

View source: R/uc_presentation.R

bcat_xaringanR Documentation

UC Xaringan presentation

Description

An R Markdown output format for remark.js slides (HTML).

Usage

bcat_xaringan(css = NULL, after_body = NULL, ...)

Arguments

css

A vector of CSS file paths. If NULL (default), function will use the css files included with the package.

after_body

relative path to HTML document to include after body of each slide. If NULL (default), function will use the insert-logo.html file included with the package.

...

arguments passed to xaringan::moon_reader

Value

An rmarkdown::output_format object for rendering Xaringan presentations.

Author(s)

Saannidhya Rawat


Rbearcat documentation built on March 21, 2026, 5:07 p.m.