util_git_check_uncommitted: Check if git repo has uncommitted changes

View source: R/utils-git.R

util_git_check_uncommittedR Documentation

Check if git repo has uncommitted changes

Description

Check if git repo has uncommitted changes

Usage

util_git_check_uncommitted(path = ".", dir_ignore = "docs/")

Arguments

path

the path to the directory to check.

dir_ignore

name of subdirectory to skip over for uncommitted files. should generally be the output directory for rmarkdown rendered files (e.g., "docs/" for bookdown projects.)

Value

Invisible NULL if path is not a Git repository or has no relevant uncommitted changes. Throws an error otherwise.

Author(s)

Saannidhya Rawat


Rbearcat documentation built on March 21, 2026, 5:07 p.m.