| bcat_fmt_comma | R Documentation |
A wrapper for scales::label_comma to format a numeric vector
to force decimal display of numbers with comma separators.
bcat_fmt_comma(x, accuracy = NULL, scale = 1, ...)
x |
a numeric vector |
accuracy |
A number to round to. Use (e.g.) |
scale |
A scaling factor: |
... |
other arguments passed to label_comma |
A character vector of formatted decimal labels with the same length as
x.
Other formatting:
bcat_fmt_date(),
bcat_fmt_dollar(),
bcat_fmt_percent(),
bcat_fmt_pvalue(),
bcat_fmt_scientific()
bcat_fmt_comma(c(5000, 10000, 8000))
bcat_fmt_comma(c(5000, 10000, 8000), scale = 10e-4, accuracy = 1, suffix = "K")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.