| bcat_fmt_date | R Documentation |
A wrapper for base::format to convert character or date vector to specfied
date/time format.
bcat_fmt_date(x, format = "%B %e, %Y", ...)
x |
a character or date/datetime vector |
format |
a date/time format string using standard POSIX specification |
... |
other arguments passed to format |
A character vector of formatted date or datetime labels with the same
length as x.
Other formatting:
bcat_fmt_comma(),
bcat_fmt_dollar(),
bcat_fmt_percent(),
bcat_fmt_pvalue(),
bcat_fmt_scientific()
bcat_fmt_date(Sys.Date())
bcat_fmt_date(c("2019-12-03", "2020-05-22"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.