| bcat_gitbook | R Documentation |
An R Markdown output format for the Gitbook format (HTML).
bcat_gitbook(css = NULL, after_body = NULL, collapse = "subsection", ...)
css |
relative path to a css formatting document.
If |
after_body |
relative path to HTML file to include after body of each chapter.
If |
collapse |
specify level at which to collapse the table of contents. |
... |
other options passed to |
An rmarkdown::output_format object for rendering Gitbook output.
Saannidhya Rawat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.