View source: R/bcat_new_quarto.R
| bcat_new_quarto | R Documentation |
Copies a UC Quarto template into the specified directory, ready to edit and render.
bcat_new_quarto(
type = c("html", "pdf", "revealjs"),
path = getwd(),
overwrite = FALSE
)
type |
Character. Template type: |
path |
Character. Directory to copy the template into. Default is current working directory. |
overwrite |
Logical. Overwrite existing files? Default is FALSE. |
An invisible character scalar giving the path to the created
template.qmd file.
Saannidhya Rawat
Other utilities:
bcat_extract_metadata(),
bcat_import_data(),
bcat_setup_rmd(),
bcat_source_rmd()
out_dir <- file.path(tempdir(), "uc-quarto")
created <- bcat_new_quarto("html", path = out_dir)
basename(created)
unlink(out_dir, recursive = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.