| bcat_pdf_book | R Documentation |
An R Markdown output format for the PDF books.
bcat_pdf_book(in_header = NULL, before_body = NULL, toc_depth = 4, ...)
in_header |
relative path to a tex formatting document included in the preamble.
If |
before_body |
relative path to a tex document included in before the body of the document.
If |
toc_depth |
depth of headers to include in table of contents |
... |
other options passed to |
An rmarkdown::output_format object for rendering PDF books.
Saannidhya Rawat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.