| util_git_check_uncommitted | R Documentation |
Check if git repo has uncommitted changes
util_git_check_uncommitted(path = ".", dir_ignore = "docs/")
path |
the path to the directory to check. |
dir_ignore |
name of subdirectory to skip over for uncommitted files. should generally be the output directory for rmarkdown rendered files (e.g., "docs/" for bookdown projects.) |
Invisible NULL if path is not a Git repository or has no
relevant uncommitted changes. Throws an error otherwise.
Saannidhya Rawat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.